@@ -8,6 +8,8 @@ from .any import any
 from .ap import ap
 from .append import append
 from .apply import apply
+from .assoc import assoc
+from .assocPath import assocPath
 from .binary import binary
 from .chain import chain
 from .clone import clone
@@ -47,6 +49,8 @@ from .hasIn import hasIn
 from .hasPath import hasPath
 from .head import head
 from .identity import identity
+from .ifElse import ifElse
+from .inc import inc
 from .indexOf import indexOf
 from .insert import insert
 from .intersection import intersection
@@ -62,6 +66,10 @@ from .keysIn import keysIn
 from .last import last
 from .lastIndexOf import lastIndexOf
 from .length import length
+from .lens import lens
+from .lensIndex import lensIndex
+from .lensPath import lensPath
+from .lensProp import lensProp
 from .lift import lift
 from .liftN import liftN
 from .lt import lt
@@ -70,7 +78,9 @@ from .map import map
 from .match import match
 from .mathMod import mathMod
 from .Max import Max
+from .maxBy import maxBy
 from .Min import Min
+from .minBy import minBy
 from .modulo import modulo
 from .multiply import multiply
 from .nAry import nAry
@@ -81,12 +91,14 @@ from .of import of
 from .omit import omit
 from .once import once
 from .Or import Or
+from .over import over
 from .partition import partition
 from .path import path
 from .pathEq import pathEq
 from .paths import paths
 from .pick import pick
 from .pickAll import pickAll
+from .pickBy import pickBy
 from .pipe import pipe
 from .pluck import pluck
 from .prepend import prepend
@@ -106,6 +118,8 @@ from .remove import remove
 from .repeat import repeat
 from .replace import replace
 from .reverse import reverse
+# pylint: disable=redefined-builtin
+from .set import set
 from .slice import slice
 from .sort import sort
 from .sortBy import sortBy
@@ -121,7 +135,9 @@ from .times import times
 from .toPairs import toPairs
 from .toPairsIn import toPairsIn
 from .toString import toString
+from .toUpper import toUpper
 from .trim import trim
+from .unapply import unapply
 from .unary import unary
 from .union import union
 from .unionWith import unionWith
@@ -129,9 +145,11 @@ from .uniq import uniq
 from .uniqBy import uniqBy
 from .uniqWith import uniqWith
 from .unnest import unnest
+from .update import update
 from .useWith import useWith
 from .values import values
 from .valuesIn import valuesIn
+from .view import view
 from .where import where
 from .xprod import xprod
 # pylint: disable=redefined-builtin
