@@ -1,14 +1,17 @@
 from math import isnan
 
-from ._helper import getAttribute
+from ._helper import getAttribute, isNegativeFloatZero
 from ._isArrayLike import _isArrayLike
 from ._isFunction import _isFunction
 from ._isNumber import _isNumber
 
 
 def _equals(a, b):
-  if _isNumber(a) and isnan(a) and _isNumber(b) and isnan(b):
-    return True
+  if _isNumber(a) and _isNumber(b):
+    if isnan(a) and isnan(b):
+      return True
+    if a == 0 and b == 0:
+      return isNegativeFloatZero(a) == isNegativeFloatZero(b)
   # pylint: disable=unidiomatic-typecheck
   if type(a) != type(b):
     return False
